::

   pip install boxmox

Set the BOXMOX environmental variable in ~/.bashrc::

   export BOXMOX_WORK_PATH=/where/you/want/boxmox/to/write/stuff/to/

Remember to close the shell and log in again for these changes to take effect.
